@@ -14,7 +14,7 @@ import functools
 def load_nn(weight_path):
 	num_H=[32,16]
 	d=0.2
-	model1, model2 = nn.ACDC(num_H,d,25)
+	model1, model2 = nn.build_acdc_3d(num_H,d,25)
 	weight_path = resource_filename('acdc_nn', 'weights/full_dataset_TL')
 	model1.load_weights(weight_path)
 	return model1, model2
@@ -54,8 +54,8 @@ def predict(model, wt_mutation, wt_profile, wt_structure, wt_chain, mt_mutation,
 			to_predict_inv = compute_nn_input(mt_mutation, mt_prot)
 	
 		# Making input in the proper shape 
-		Xm_d, X1D_d, X3D_d = nn.mkInp(np.asarray(to_predict_dir).astype(np.float32), 500)
-		Xm_i, X1D_i, X3D_i = nn.mkInp(np.asarray(to_predict_inv).astype(np.float32), 500)
+		Xm_d, X1D_d, X3D_d = nn.mkInp_3d(np.asarray(to_predict_dir).astype(np.float32), 500)
+		Xm_i, X1D_i, X3D_i = nn.mkInp_3d(np.asarray(to_predict_inv).astype(np.float32), 500)
 
 		prediction = model.predict([X3D_d, X1D_d, Xm_d , X3D_i, X1D_i, Xm_i])
 		return prediction[0][0][0]
@@ -78,7 +78,7 @@ def main():
 	parser.add_argument('--weights', metavar='NN-WEIGHTS', 
 		default=resource_filename('acdc_nn', 'weights/full_dataset_TL'), 
 		help='path to the network weights, in tensorflow format') # FIXME what is the name of the format?
-	subparsers = parser.add_subparsers(dest='command', metavar='CMD', required=True)
+	subparsers = parser.add_subparsers(metavar='COMMAND', dest='command', title='COMMAND')
 
 	single_parser = subparsers.add_parser('single', help='predict a single mutation')
 	single_parser.add_argument('wt_mutation', metavar='MUT', help='mutation (e.g. Q339N)')
@@ -88,7 +88,7 @@ def main():
 		help='ID of the PDB chain where the mutation occurs')
 
 	inverse_parser = subparsers.add_parser('inverse', 
-		help='predict a single mutation using also the inverse structure')
+		help='predict a single mutation using also the mutated protein information')
 	inverse_parser.add_argument('wt_mutation', metavar='MUT', help='direct mutation (e.g. Q339N)')
 	inverse_parser.add_argument('wt_profile', metavar='WT-PROF', 
 		help='profile file path for the wild-type protein')
@@ -113,9 +113,7 @@ def main():
 	args = parser.parse_args()
 
 	if args.command is None:
-		parser.print_usage()
-		parser.error('the following arguments are required: CMD')
-		sys.exit(0)
+		parser.error('the following arguments are required: COMMAND')
 	
 	base_arg_list = ['wt_mutation', 'wt_profile', 'wt_structure', 'wt_chain', 'mt_mutation', 'mt_profile', 'mt_structure', 'mt_chain']
 
@@ -127,7 +125,6 @@ def main():
 		print(ddg, file=args.output)
 	elif args.command == 'batch':
 		muts = pd.read_csv(args.mutation_table, sep='\t', names=base_arg_list)
-		print(muts)
 		for row, mut in muts.iterrows():
 			# check na values
 			if mut[base_arg_list[:4]].count() < 4:
